==> react-molecule-drawer-3.3.0.tgz: package/lib/Drawer.js <==
import { forwardRef, useEffect, useState, useCallback } from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import useEventListener from '@s-ui/react-hooks/lib/useEventListener';
import useControlledState from '@s-ui/react-hooks/lib/useControlledState';
import { ANIMATION_DURATION, PLACEMENTS, SIZES } from './settings';
import { jsx as _jsx } from "react/jsx-runtime";
var MoleculeDrawer = /*#__PURE__*/forwardRef(function (_ref, forwardedRef) {
  var _ref$animationDuratio = _ref.animationDuration,
      animationDuration = _ref$animationDuratio === void 0 ? ANIMATION_DURATION.FAST : _ref$animationDuratio,
      children = _ref.children,
      _ref$isOpen = _ref.isOpen,
      isOpen = _ref$isOpen === void 0 ? false : _ref$isOpen,
      onOpen = _ref.onOpen,
      onClose = _ref.onClose,
      _ref$placement = _ref.placement,
      placement = _ref$placement === void 0 ? PLACEMENTS.LEFT : _ref$placement,
      _ref$size = _ref.size,
      size = _ref$size === void 0 ? SIZES.AUTO : _ref$size,
      target = _ref.target;

  var _useControlledState = useControlledState(isOpen),
      isOpenState = _useControlledState[0],
      setIsOpenState = _useControlledState[1]; // inner state


  var _useState = useState(isOpen),
      isOpenedState = _useState[0],
      setIsOpenedState = _useState[1]; // transition delayed state


  useEffect(function () {
    if (target !== undefined) {
      target.current.style.position = 'relative';
      target.current.style.overflow = 'hidden';
    }
  }, [target]);
  useEventListener('keydown', function (event) {
    if (isOpenState === false) return;
    event.preventDefault();

    if (event.key === 'Escape') {
      setIsOpenState(false, true);
    }
  });
  var onTransitionEndHandler = useCallback(function (event) {
    setIsOpenedState(isOpenState);

    if (isOpenState && !isOpenedState && typeof onOpen === 'function') {
      onOpen(event, {
        isOpen: isOpenState
      });
    } else if (!isOpenState && isOpenedState && typeof onClose === 'function') {
      onClose(event, {
        isOpen: isOpenState
      });
    }
  }, [setIsOpenedState, isOpenState, isOpenedState, onClose, onOpen]);
  return /*#__PURE__*/_jsx("div", {
    onTransitionEnd: onTransitionEndHandler,
    className: cx('react-MoleculeDrawer-content', "react-MoleculeDrawer-content--placement-" + placement, "react-MoleculeDrawer-content--size-" + size, "react-MoleculeDrawer-content--animationDuration-" + animationDuration, "react-MoleculeDrawer-content--state-" + (isOpenState ? 'opened' : 'closed'), {
      'react-MoleculeDrawer-content--placement': typeof target === 'undefined'
    }),
    ref: forwardedRef,
    children: children
  });
});
MoleculeDrawer.displayName = 'MoleculeDrawer';
export default MoleculeDrawer;

==> react-molecule-drawer-3.4.0.tgz: package/lib/Drawer.js <==
import { forwardRef, useEffect, useCallback } from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import useEventListener from '@s-ui/react-hooks/lib/useEventListener';
import useControlledState from '@s-ui/react-hooks/lib/useControlledState';
import { ANIMATION_DURATION, PLACEMENTS, SIZES } from './settings';
import { jsx as _jsx } from "react/jsx-runtime";
var MoleculeDrawer = /*#__PURE__*/forwardRef(function (_ref, forwardedRef) {
  var _ref$animationDuratio = _ref.animationDuration,
      animationDuration = _ref$animationDuratio === void 0 ? ANIMATION_DURATION.FAST : _ref$animationDuratio,
      children = _ref.children,
      _ref$isOpen = _ref.isOpen,
      isOpen = _ref$isOpen === void 0 ? false : _ref$isOpen,
      onOpen = _ref.onOpen,
      onClose = _ref.onClose,
      _ref$placement = _ref.placement,
      placement = _ref$placement === void 0 ? PLACEMENTS.LEFT : _ref$placement,
      _ref$size = _ref.size,
      size = _ref$size === void 0 ? SIZES.AUTO : _ref$size,
      target = _ref.target;

  var _useControlledState = useControlledState(isOpen),
      isOpenState = _useControlledState[0],
      setIsOpenState = _useControlledState[1]; // inner state


  useEffect(function () {
    if (target !== undefined) {
      target.current.style.position = 'relative';
      target.current.style.overflow = 'hidden';
    }
  }, [target]);
  useEventListener('keydown', function (event) {
    if (isOpenState === false) return;
    event.preventDefault();

    if (event.key === 'Escape') {
      setIsOpenState(false, true);
      onClose(event, {
        isOpen: false
      });
    }
  });
  var onTransitionEndHandler = useCallback(function (event) {
    if (isOpenState && typeof onOpen === 'function') {
      onOpen(event, {
        isOpen: isOpenState
      });
    } else if (!isOpenState && typeof onClose === 'function') {
      onClose(event, {
        isOpen: isOpenState
      });
    }
  }, [isOpenState, onClose, onOpen]);
  return /*#__PURE__*/_jsx("div", {
    onTransitionEnd: onTransitionEndHandler,
    className: cx('react-MoleculeDrawer-content', "react-MoleculeDrawer-content--placement-" + placement, "react-MoleculeDrawer-content--size-" + size, "react-MoleculeDrawer-content--animationDuration-" + animationDuration, "react-MoleculeDrawer-content--state-" + (isOpenState ? 'opened' : 'closed'), {
      'react-MoleculeDrawer-content--placement': typeof target === 'undefined'
    }),
    ref: forwardedRef,
    children: children
  });
});
MoleculeDrawer.displayName = 'MoleculeDrawer';
export default MoleculeDrawer;
